import 'package:bytedesk_kefu/model/requestThread.dart';
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';
import 'package:bytedesk_kefu/model/model.dart';

@immutable
abstract class ThreadState extends Equatable {
  // ThreadState([List props = const []]) : super(props);
  const ThreadState();

  @override
  List<Object> get props => [];
}

class ThreadUninitialized extends ThreadState {
  @override
  String toString() => 'ThreadUninitialized';
}

class InitialThreadState extends ThreadState {
  @override
  List<Object> get props => [];

  @override
  String toString() => 'InitialThreadState';
}

class ThreadEmpty extends ThreadState {
  @override
  String toString() => 'ThreadEmpty';
}

class ThreadLoading extends ThreadState {
  @override
  String toString() => 'ThreadLoading';
}

class ThreadVisitorLoading extends ThreadState {
  @override
  String toString() => 'ThreadVisitorLoading';
}

class ThreadHistoryLoading extends ThreadState {
  @override
  String toString() => 'ThreadHistoryLoading';
}

class ThreadLoadError extends ThreadState {
  @override
  String toString() => 'ThreadLoadError';
}

class ThreadLoadSuccess extends ThreadState {
  final List<Thread>? threadList;

  const ThreadLoadSuccess(this.threadList);

  ThreadLoadSuccess copyWith({List<Thread>? threadList}) {
    return ThreadLoadSuccess(threadList);
  }

  @override
  List<Object> get props => [threadList!];

  @override
  String toString() => 'ThreadLoadSuccess { threadList: ${threadList!.length} }';
}

class RequestThreadSuccess extends ThreadState {
  final RequestThreadResult threadResult;

  const RequestThreadSuccess(this.threadResult);

  @override
  List<Object> get props => [threadResult];

  @override
  String toString() => 'RequestThreadSuccess';
}

class RequestAgentSuccess extends ThreadState {
  final RequestThreadResult threadResult;

  const RequestAgentSuccess(this.threadResult);

  @override
  List<Object> get props => [threadResult];

  @override
  String toString() => 'RequestAgentSuccess';
}

class RequestContactThreadSuccess extends ThreadState {
  final RequestThreadResult threadResult;

  const RequestContactThreadSuccess(this.threadResult);

  @override
  List<Object> get props => [threadResult];

  @override
  String toString() => 'RequestContactThreadSuccess';
}

class RequestGroupThreadSuccess extends ThreadState {
  final RequestThreadResult threadResult;

  const RequestGroupThreadSuccess(this.threadResult);

  @override
  List<Object> get props => [threadResult];

  @override
  String toString() => 'RequestGroupThreadSuccess';
}